\name{PT}
\alias{PT}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Traverse rpart object using Tcl Tk GUI}
\description{ 
	Function uses Tcl/Tk widgets to enable a tree (or, more generally,
	an rpart object) to be traversed graphically. This is useful
	for complicated trees and/or where variable descriptions are
	long.
}
\usage{
PT(rpart, textfn = NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{rpart}{ An rpart object }
  \item{textfn}{ A function that converts a variable name into text } }

\details{
	Suppose one has a rpart (or tree in Splus) classification or
	regression tree. A common task is to take a new case or
	individual and use the tree to make a decision about the
	new case (or to put it another way to classify the class membership
	of the new case).

	One could use the tree plot to decide this and at each node make
	a decision and follow the edges of the tree to a leaf which contains
	the final classification value. However, with some trees there are
	two problems that PT is designed to overcome. The first is that
	some trees are huge. Plots of such trees are often incomprehensible.
	The second is that a description of the decision to be made at a
	node (or even every node) might require a significant amount of
	supportive text. It might be impractical to augment a tree plot
	with a large amount of text at each node as this would, again,
	render the tree plot incomprehensible.

	This routine presents, for each node, starting with the root, a
	little window (widget) which asks the user to take their new case and
	answer a question in relation to the new case. The software
	takes their answer and automatically works out which is the next
	node to visit and question to ask. Eventually, it reaches a leaf
	and displays the predicated classification (or predicted value,
	for regression) for the new case (and it also returns it to the
	calling function).

	The questions are answered by clicking the relevant radiobutton and
	then clicking submit.

	A feature of PT is that for each question asked an optional
	amount of supportive text can be supplied. This text appears in
	the window where the question is being asked. This feature is
	useful as it means that the full information about the question
	being asked can be displayed altogether without, say, having to
	make a separate and inconvenient reference to a separate document.

	The optional text is supplied through the textfn argument.
	This function should have one argument which can be any of the
	variable names in the tree (which, of course, are some of the
	original variables in the dataframe from which the tree was
	constructed. The appropriate text should be supplied as a single
	character string (although it can contain newline characters, etc).
	The textfn function should also have the argument web such that
	when this argument is FALSE a single string of text is produced
	(for this function). [When the web argument is TRUE then this is
	designed for use with the pinktoe function and it would be
	desirable for textfn to produce the same text but printed out
	(to a specified file) in HTML format.]
}
\value{The classification (or predicted value) for the new case
whose characteristics that one specifies through answering the questions.
}
\references{ www.stats.bris.ac.uk/~magpn/Research/Pinktoe/pinktoe.htm }
\author{ Guy P Nason}
\note{ This package contains another function pinktoe which produces a similar
system but in terms of a CGI-HTML web based system (which is harder to use but
produces code that can be accessed by any web browser by any one)}

\seealso{ \code{\link{pinktoe}}}
\examples{
#
# Load rpart library (needed for tree building and execution of PT
#
library("rpart")
library("tcltk")
data("mpincdf99")
#
# Use supplied function to create a suitable example.
#
z.edm <- makeEDMtree()
#
# Plot tree to look at the basic structure
#
plot(z.edm)
text(z.edm)
#
# Now use PT to graphically traverse tree
#
data("edmbigtext")
\dontrun{ PT(z.edm, textfn=edm.text)}
#
# Successive widgets appear. You can answer each one using the
# default options if you like (the final classification will be
# "Conservative". 
#
# If you have more time then notice that the order of questioning
# and your answers follow the edge structure of the tree.
#
# Notice the large amount of text supplied with each question (variable)
# This is achieved by the edm.text function.
#
}
\keyword{ iplot }
\keyword{ tree }

\eof
\name{PTTclQ}
\alias{PTTclQ}
\title{ Traverse tree structure calling appropriate GUI widgets}
\description{
	PTTclQ takes a tree and a row number (indexing a node).
	If that row describes a leaf then the function returns the
	yval for that leaf. If the row describes a decision node
	the function calls a GUI Tcl/Tk widget to ask the user
	what decision is necessary for that node. The result of
	the decision is used to recursively call PTTclQ for the next
	node. 
}
\usage{
PTTclQ(rpart, row, textfn, tittext, stateprintfn)
}
\arguments{
  \item{rpart}{ \code{rpart} object that you wish to traverse }
  \item{row}{ \code{row} the node at which the current decision is to be made }
  \item{textfn}{ Function to provide text given a variable name }
  \item{tittext}{ Currently unused. Reserved for future use }
  \item{stateprintfn}{ Currently unused. Reserved for future use}
}
\details{
	Description says it all.
}
\value{This function is recursive. However, eventually a leaf must be
	reached and a yval returned back to the calling function. The
	yval is either a numeric value corresponding to a predicted
	value for the case in regression, or an indexed into a factor
	for a classification tree.
}
\references{  }
\author{Guy P Nason}
\note{ Not intended for general use }


\seealso{ \code{\link{PT}}}
\examples{
#
# Not intended for general user use
#
}
\keyword{ internal }% at least one, from doc/KEYWORDS

\eof
\name{PTdialog.leaf}
\alias{PTdialog.leaf}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Display text and ok button in a Tcl/Tk widget }
\description{
	Merely displays some text and an ok button in a Tcl/Tk widget
	which disappears when OK is clicked.
}
\usage{
PTdialog.leaf(leaftext)
}
\arguments{
  \item{leaftext}{ Character string to be displayed }
}
\details{
	As description
}
\value{
  None
}
\references{  }
\author{Guy P Nason }
\note{ Not intended for general user use }

\seealso{ \code{\link{PT}}}
\examples{
#
# Not intended for general use.
#
# Could do:
#
library("tcltk")
\dontrun{PTdialog.leaf("Hello World")}
#
# which displays a box with text and ok button!
#
}
\keyword{ internal }% at least one, from doc/KEYWORDS
\keyword{ IO }% __ONLY ONE__ keyword per line

\eof
\name{PTdialog.rpartq}
\alias{PTdialog.rpartq}
\title{ Display a dialog box with text, radiobuttons and submit using Tcl/Tk and return submitted answer }
\description{
	Opens a Tcl/Tk GUI widget with some text, a two-button radio button and decision
	text and submit/reset buttons. Once submit is pressed the
	state of the radiobutton is returned.
}
\usage{
PTdialog.rpartq(questiontext, qopts = NULL, qno = NULL, explaintext = NULL)
}
\arguments{
  \item{questiontext}{ Character string containing question relating to radiobutton }
  \item{qopts}{ Character string containing text describing one option of the radiobutton }
  \item{qno}{ Character string containing text describing the other option of the radiobutton. }
  \item{explaintext}{ Character string containing (extended) text presented before the radiobutton }
}
\details{
	A simple Tcl/Tk widget display function that permits some text
	to be displayed, a question to be displayed and two answers
	with two sets of text strings containing the answer text.
}
\value{Returns the qopts or qno string (indicating the answer) if these
	are not NULL. Otherwise returns "yes" or "no". 
}
\references{ \url{http://www.stats.bris.ac.uk/~magpn/Research/Pinktoe/pinktoe.htm} }
\author{Guy P Nason}
\note{ Not intended for general user use }
\examples{
    library("tcltk")
\dontrun{
PTdialog.rpartq("Is it possible for a swallow to carry a coconut?", qopts="Yes, certainly", qno="No way", explaintext="A question from Monty Python's Holy Grail")}
}
\keyword{ internal }% at least one, from doc/KEYWORDS
\keyword{ IO }% __ONLY ONE__ keyword per line

\eof
\name{PTprocstring}
\alias{PTprocstring}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Converts splits information present in an rpart object to an S like format }
\description{
	Splits information (which can be obtained indirectly from path.rpart)
	in R comes in phrases like "Country=abc" (for factor variables)
	or "Weight<=6" (for numeric variables) needs to be converted into
	the format ":abc" and "<=6" to match the S-like format.
}
\usage{
PTprocstring(s, vtype)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{s}{ Splits information string from \code{rpart} (via \link{path.rpart}) }
  \item{vtype}{ Whether the variable is "factor" or not }
}
\details{
	If \code{vtype} is not a factor then the string is treated as if
	it were numeric.
}
\value{
	A splits string but in S format.
}
\references{ \code{\link{PT}}, \code{\link{pinktoe}} }
\author{Guy P Nason }
\note{ Not intended for general use}


\seealso{ \code{\link{PT}}, \code{\link{pinktoe}} }
\examples{
#
# Process string "Country=abc" for factor variable
#
    PTprocstring("Country=abc", "factor")
#
# [1] ":abc"
#
# Process string "Weight<=6" for numeric variable
#
    PTprocstring("Weight<=6", vtype="numeric")
#
# [1] "<=6"
#
}
\keyword{ internal }% at least one, from doc/KEYWORDS
\keyword{ manip }% __ONLY ONE__ keyword per line

\eof
\name{edm.text}
\alias{edm.text}
\title{ Example of a textfn function for pinktoe/PT}
\description{
	An example textfn text function for the EDM data set
}
\usage{
edm.text(n, web = TRUE, file = "", append = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{n}{ A EDM variable name, such as "EDM29" }
  \item{web}{ If TRUE then the output is catted and appended to an HTML file. If FALSE
	the function returns a single character string with the desired text (including
	newlines, etc)}
  \item{file}{ The name of the file to cat the text to (if web==TRUE) }
  \item{append}{ Usually should be TRUE (I know the default is FALSE! Flip) }
}
\details{
	This functions produces text (either in HTML format which gets catted to a file, or returned as 
	a single character string) in response to an EDM number. The text describes the EDM. The actual text
	is stored in the character vector \code{edmbigtext}, the numbers of EDMs that this character vector contains
	is given in the object \code{edmnumswehave}.
}
\value{ If web==TRUE then nothing is returned. Otherwise, a single string containing the EDM text is produced.
}
\references{ 
\url{http://www.stats.bris.ac.uk/~magpn/Research/Pinktoe/Welcome.html}
}
\author{Guy P Nason }
\note{ Not intended for general user use}

\seealso{ \code{\link{pinktoe}}}
\examples{
#
# Which EDMs do we have text for
#
data(edmnumswehave)
data(edmbigtext)
edmnumswehave
#[1]  29  52  89 110 125 142 175 297 346 391 445 476 493 516 657 770 939
#
#
# Ok. Lets look at the text for EDM29. We'll set web=TRUE to get HTML output
#
edm.text("EDM29", web=TRUE)
#<EM>RACE  RELATIONS  </EM>
#<P>
#That  this  House  accepts  the  fact  that  the  
#United  Kingdom  is  a  multi-racial  society;  reasserts  the  
#right  of  all  individuals  to  enjoy  equal  rights  
#irrespective  of  their  race,  colour  or  creed;  deplores  
#the  fact  that  racial  discrimination  continues  to  blight  
#the  lives  of  many  British  citizens,  and  many  
#other  ethnic  minorities  who  live  in  the  United  
#Kingdom;  and  urges  the  Home  Secretary  to  implement  
#the  recommendations  by  the  Commission  for  Racial  Equality  
#and  reform  the  Race  Relations  Act  1976.  <BR>
#
# Do the same thing but return as a character string
#
edm.text("EDM29", web=FALSE)
#[1] " RACE RELATIONS \n\n That this House accepts the fact that the\n United Kingdom is a multi-racial society; reasserts the\n right of all individuals to enjoy equal rights\n irrespective of their race, colour or creed; deplores\n the fact that racial discrimination continues to blight\n the lives of many British citizens, and many\n other ethnic minorities who live in the United\n Kingdom; and urges the Home Secretary to implement\n the recommendations by the Commission for Racial Equality\n and reform the Race Relations Act 1976.\n"
}
\keyword{ datagen }% at least one, from doc/KEYWORDS

\eof
\name{edmbigtext}
\alias{edmbigtext}
\docType{data}
\title{ Character vector containing all text necessary for the edm.text function} 
\description{
	The function edm.text uses this data set to extract text for
	various EDMs. The numbers of the EDMs stored in this vector are listed
	in the vector \code{\link{edmnumswehave}}
}
\usage{data(edmbigtext)}
\format{ A character vector containing 1729 elements.
}
\source{Originally the UK Houses of Parliament, but either through Her Majesty's Stationary Office or
\code{edm.ais.co.uk}. 
}
\examples{
data(edmbigtext)
#
# Using edm.text
#
edm.text("EDM939")
#<EM>USE  OF  PARLIAMENTARY  TIME  </EM>
#<P>
#That  this  House  welcomes  the  recommendation  by  the  
#Modernisation  Committee  to  timetable  business  so  that  the  
#last  stand  alone  votes  are  taken  at  10.00  
#p.m.  thereby  ending  the  practice  of  making  legislation  
#in  the  early  hours  of  the  morning;  notes  
#that  backbenchers  and  opposition  parties  are  to  be  
#given  control  over  how  the  time  for  debating  
#a  bill  is  used;  and  believes  that  this  
#will  make  for  better  scrutiny,  better  legislation  and  
#better  government.  <BR>
}
\keyword{datasets}

\eof
\name{edmnum99}
\alias{edmnum99}
\docType{data}
\title{Complete list of EDM numbers for 1999} 
\description{
	A complete list of EDM numbers for 1999. This is also the second dimnames component of
	\code{\link{mpinc99}}.
}
\usage{data(edmnum99)}
\format{
	A vector of 1243 EDM numbers including amendments. The numbers are stored as character
	strings since some of them have letters in! E.g. "930A1" is an amendment of "930".
}
\source{Originally the UK Houses of Parliament, but either through Her Majesty's Stationary Office or
\code{edm.ais.co.uk}. 
}
\examples{
data(edmnum99)
#
# Let's just have a look at a few
#
edmnum99[11:20]
# [1] "11"   "12"   "12A1" "13"   "14"   "15"   "16"   "17"   "18"   "19"  
#
# Note that EDM12 has an amendment also, EDM12A1
#
}
\keyword{datasets}

\eof
\name{edmnumswehave}
\alias{edmnumswehave}
\docType{data}
\title{ List of the EDM numbers that can be accessed by the edm.text function} 
\description{
	Only some of the EDMs listed in \code{edmnum99} are present in the \code{edmbigtext}
	vector which edm.text accesses. The ones that are present are listed in the
	edmnumswehave vector.
}
\usage{data(edmnumswehave)}
\format{An integer vector of 17 elements. Each one is an EDM number that can be accessed through edm.text
}
\source{Originally the UK Houses of Parliament, but either through Her Majesty's Stationary Office or
\code{edm.ais.co.uk}. 
}
\examples{
data(edmnumswehave)
#
# Not really worth an example
#
}
\keyword{datasets}

\eof
\name{genedmhtml}
\alias{genedmhtml}
\title{Generate HTML and perl files to enable tree traversal}
\description{
	Called by pinktoe to traverse a tree and generate appropriate
	perl and HTML files that enable a CGI-enabled web-server to
	graphically traverse a tree.
}
\usage{
genedmhtml(treeobj, noderow, edmtextfn, edmtittext, cgibindir, htmldir, localdir, stateprintfn, requirelib, commonhtml)
}
\arguments{
  \item{treeobj}{ A \code{tree} or \code{rpart} object to traverse }
  \item{noderow}{ The row to begin at}
  \item{edmtextfn}{ A function that can print out explanatory text given a variable name (see web help page and \code{edm.text} example. }
  \item{edmtittext}{ Prints out a title string given a variable name }
  \item{cgibindir}{ A character string containing the directory where the perl
        files generated by pinktoe (with the extension \code{.pl}) will be
        stored.
        (This should be the directory part of the URL of the cgi-bin
        directory). }

  \item{htmldir}{ A character string containing the directory where the HTML
                files generated by pinktoe (with the extension \code{.htm})
                will be stored.  (This should be a pathname understood and
                able to be found by perl).  }
  \item{localdir}{A local location to store both the HTML and perl files
        immediately after they are generated }

  \item{stateprintfn}{A user-supplied function that decides what to do when
        supplied with the \code{yval} reached at the leaf of a tree. Some
        text can be output, or maybe a perl function call.  }

  \item{requirelib}{A library of perl functions that can be called by, e.g.
        \code{stateprintfn}. The library that this refers to
        should reside in the \code{cgibin} directory. If no function calls
        are planned then it doesn't matter what argument is supplied.}

  \item{commonhtml}{A user-supplied function that prints out some HTML code.
        This is appended to every HTML web page.}

}
\details{
}
\value{ No deliberate return value.  }
\references{ 
\url{http://www.stats.bris.ac.uk/~magpn/Research/Pinktoe/Welcome.html}
}
\author{Guy P Nason }
\note{ Not intended for general user use}

\seealso{ \code{\link{pinktoe}}}
\examples{
#
#Not intended for general user use
#
}
\keyword{ datagen }% at least one, from doc/KEYWORDS

\eof
\name{genericcommonhtml}
\alias{genericcommonhtml}
\title{ An example of some common html to go at the end of HTML pages for Pinktoe}
\description{
	Title says it all. This function could be supplied to \code{\link{pinktoe}} as the \code{commonhtml} argument.
}
\usage{
genericcommonhtml(file, append)
}
\arguments{
  \item{file}{ The name of the HTML file to append the HTML to}
  \item{append}{ Should be TRUE }
}
\details{
	Title says it all, see example below.
}
\value{ No value returned.
}
\references{ 
\url{http://www.stats.bris.ac.uk/~magpn/Research/Pinktoe/Welcome.html}
}
\author{Guy P Nason }
\note{ Not intended for general user use}

\seealso{ \code{\link{pinktoe}}}
\examples{
#
# The "" makes the output go to standard output (ie on the console)
#
genericcommonhtml(file="", append=TRUE)
#<a href="http://www.stats.bris.ac.uk/~magpn">Return to <EM>Guy Nason's</EM> home page</a>
#
# Of course this is an example function which you can modify to say whatever you like!
}
\keyword{ misc }% at least one, from doc/KEYWORDS

\eof
\name{kyphosis.text}
\alias{kyphosis.text}
\title{ Print explanatory text concerning kyphosis variables.}
\description{
	Given a variable name this function prints out explanatory text in HTML
}
\usage{
kyphosis.text(n, file = "", append = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{n}{ A \code{kyphosis} variable. Could be "Start", "Age", "Number"}
  \item{file}{ File to write HTML to}
  \item{append}{ Should be TRUE}
}
\details{
	As Description. This is an example function of a possible argument to the \code{textfn}
    argument of \code{\link{pinktoe}}
}
\value{No value is returned
}
\references{ 
\url{http://www.stats.bris.ac.uk/~magpn/Research/Pinktoe/Welcome.html}
}
\author{Guy P Nason }
\note{ Not intended for general user use}

\seealso{ \code{\link{pinktoe}}}
\examples{
#
# Here is a simple example
#
kyphosis.text("Start")
#<BR>
#Variable:  Start : The beginning of the range of vertabrae involved<BR>
}
\keyword{ datagen }% at least one, from doc/KEYWORDS

\eof
\name{kyphosisprint}
\alias{kyphosisprint}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Example stateprintfn for the pinktoe function arising from the kyphosis example}
\description{
	This function is an example of the type of function that could be supplied to the \code{stateprintfn} argument of the
	\code{\link{pinktoe}} function. Given a \code{yval} from \code{z.kyphosis} tree (such as "present" or "absent") it produces
	perl code to call an appropriate perl function (it actually calls the present or absent perl functions that are
	defined by the \code{requirelib} argument of \code{\link{pinktoe}} function
}
\usage{
kyphosisprint(yval, file = "", append = FALSE)
}
\arguments{
  \item{yval}{ A \code{z.kyphosis} yval. This is either "present" or "absent" }
  \item{file}{ Where to cat the output }
  \item{append}{ Should be TRUE }
}
\details{
	As Description
}
\value{No value returned }
\references{ 
\url{http://www.stats.bris.ac.uk/~magpn/Research/Pinktoe/Welcome.html}
}
\author{Guy P Nason }
\note{ Not intended for general user use}

\seealso{ \code{\link{pinktoe}}}
\examples{
#
# A quick example. The file here is specified as "" to cat to standard output
#
kyphosisprint("present")
# &present;
}
\keyword{ datagen }% at least one, from doc/KEYWORDS

\eof
\name{kyphosistittext}
\alias{kyphosistittext}
\title{ An example of a tittext function for the pinktoe function with the kyphosis example.}
\description{
	Returns a character string in response to a variable. Serves as an example \code{tittext} function for the
	\code{\link{pinktoe}} function.
}
\usage{
kyphosistittext(label)
}
\arguments{
  \item{label}{ A variable label. Could be "Start", "Age", "Number".}
}
\details{
	This is an example function that could be supplied as the \code{tittext} argument for the \code{\link{pinktoe}}
	function. All this function does is return a particular character string in response to a text string
	argument (which is supplied by the calling function as the variable from the tree in question). 
	The returned character string is used as the title for the associated web page that gets produced for each
	HTML file produced by \code{\link{pinktoe}}.
}
\value{
	A character string containing the response text.
}
\references{ 
\url{http://www.stats.bris.ac.uk/~magpn/Research/Pinktoe/Welcome.html}
}
\author{Guy P Nason }
\note{ Not intended for general user use}

\seealso{ \code{\link{pinktoe}}}
\examples{
#
# Try it out with the variable name "Start"
#
kyphosistittext("Start")
#[1] "Variable: Start"
}
\keyword{ datagen }% at least one, from doc/KEYWORDS

\eof
\name{makeEDMtree}
\alias{makeEDMtree}
\title{ Construct a tree for one of the examples showing how pinktoe works}
\description{
	Merely constructs a tree (\link{rpart}) object.
}
\usage{
makeEDMtree()
}
%- maybe also 'usage' for other objects documented here.
\details{
	Constructs a particular tree using a given data frame and a list of variables (the ones in
	\code{\link{edmnumswehave}}. When transferring code between S and R sometimes tree objects
	(in S) differ from their "equivalent" partners (\code{\link{rpart}} objects) in R. Hence it is
	useful to sometimes be able to recompute them for the particular package in question.
}
\value{ An object of class \code{rpart} which is the made tree.}
\references{ 
\url{http://www.stats.bris.ac.uk/~magpn/Research/Pinktoe/Welcome.html}
}
\author{Guy P Nason }
\note{ Useful for constructing an example}

\seealso{ \code{\link{pinktoe}}}
\examples{
#
# Build the tree after loading rpart library
#
library("rpart")
data("mpincdf99")
mpincdf99tree <- makeEDMtree()
}
\keyword{ datagen }% at least one, from doc/KEYWORDS

\eof
\name{mpall3}
\alias{mpall3}
\docType{data}
\title{ Master database of MP information concerned with EDM example}
\description{
	A list containing several components. Each component is some kind of vector with each row of each vector
	containing information about a given MP. Not really used in the examples but useful for the author to have
	around.
}
\usage{data(mpall3)}
\format{
  The format is:
List of 7 components
 \$ mpn     : Factor w/ 670 levels containing the names of the MPs
 \$ mpcon   : Factor w/ 660 levels containing the constituencies of MPs
 \$ mpparty : Factor w/ 16 levels containing MPs' party affiliation.
 \$ mpregion: Factor w/ 9 levels containing the region containing the MPs' constituencies.
 \$ mpgender: Factor w/ 2 levels gender of MP.
 \$ mpage   : num [1:670] Age of MP at given date.
 \$ mpagecod: num [1:670] Age rangeof MP
}
\source{Nason, G.P. (2001) Early Day Motions: exploring backbench opinion during 1997-2000. \emph{Technical Report} 01:11, Department
 of Mathematics, University of Bristol.
}
\examples{
data(mpall3)
#
# The name of MP number 3
#
mpall3$mpn[3]
#
# This record corresponds to Irene Adams
#
#[1] Adams, Irene
#670 Levels: Abbott, Miss Diane Adams, Gerry# Adams, Irene ... Young, Rt Hon Sir George Bt
mpall3$mpcon[3]
#
# Her constituency is Paisley North
#
#[1] Paisley North
#660 Levels: Aberavon Aberdeen Central Aberdeen North ... York, City of
mpall3$mpparty[3]
#
# She is a Labour MP
#
#[1] Lab
#16 Levels: Con DCWM DU Ind LDem Lab Lib PC SDLP SF SNP SPK Scot Lab UKU ... WW
mpall3$mpregion[3]
#
# Her constituency is in the North West of England
#
#[1] NorthWest
#9 Levels: London Midland NI NorthEast NorthWest Scotland ... Wales
#
# She is Female
#
mpall3$mpgender[3]
#[1] F
#Levels: F M
mpall3$mpage[3]
#
# She was 53 at the census date
#
#[1] 53
mpall3$mpagecod[3]
#
# She was in her fifties
#
#[1] 5
}
\keyword{datasets}

\eof
\name{mpinc99}
\alias{mpinc99}
\docType{data}
\title{ EDM signing database for 1999} 
\description{
	A binary matrix containing a zero/one entry for each cell which represents whether or not a
	given MP signed a given Early Day Motion.
}
\usage{data(mpinc99)}
\format{There are 549 MPs and 1243 EDMs.
}
\source{Nason, G.P. (2001) Early Day Motions: exploring backbench opinion during 1997-2000. \emph{Technical Report} 01:11, Department
 of Mathematics, University of Bristol.
}
\examples{
data(mpinc99)
## maybe str(mpinc99) ; plot(mpinc99) ...
#
# Did Irene Adams sign EDM3 ?
#
mpinc99[2, 3]
# [1] 0
#
# No, she didn't!
}
\keyword{datasets}

\eof
\name{mpincdf99}
\alias{mpincdf99}
\docType{data}
\title{ EDM signing database for 1999 and party affiliation for MPs} 
\description{
	A dataframe. Each row represents an MP. The first entry in each row contains the party affiliation for that MP.
	Subsequent entries correspond to the factor SIGNED/NOT SIGNED indicating whether that MP did or did not sign the
	EDM described by that column. 
}
\usage{data(mpincdf99)}
\format{A dataframe containing 549 MPs (rows) and 1244 columns (one for party membership and the rest for EDMs).
}
\source{Nason, G.P. (2001) Early Day Motions: exploring backbench opinion during 1997-2000. \emph{Technical Report} 01:11, Department
 of Mathematics, University of Bristol.
}
\examples{
data(mpincdf99)
## maybe str(mpincdf99) ; plot(mpincdf99) ...
#
# Let's look at the first 5 MPs and the first 4 EDMs.
#
mpincdf99[1:5,1:5]
#                  party   EDM1 EDM2   EDM3   EDM4
#Abbott/Diane        Lab SIGNED  NOT SIGNED    NOT
#Adams/Irene         Lab    NOT  NOT    NOT SIGNED
#Ainger/Nick         Lab    NOT  NOT    NOT    NOT
#Ainsworth/Peter     Con    NOT  NOT    NOT    NOT
#Alexander/Douglas   Lab    NOT  NOT    NOT    NOT
#
# So, Diane signed EDM1 and EDM3 and not EDM2 and EDM4 etc....
}
\keyword{datasets}

\eof
\name{partycommonhtml}
\alias{partycommonhtml}
\title{ Function to produce HTML at the end of all EDM HTML pages}
\description{
	Often at the end of an HTML file code which is common across a set of pages is put.
	For example, a link back to some contents page. This function produces such code
	for the EDM example.
}
\usage{
partycommonhtml(file, append)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{file}{ The HTML file to append the code to  }
  \item{append}{ Should always be TRUE }
}
\details{
	Generates HTML code which is going to be common to all pages generated by a given
	\code{\link{pinktoe}} run.
}
\value{ No value}
\references{ 
\url{http://www.stats.bris.ac.uk/~magpn/Research/Pinktoe/Welcome.html}
}
\author{Guy P Nason }
\note{ Not intended for general user use}

\seealso{ \code{\link{pinktoe}}}
\examples{
#
# A simple example where filename="" to show result on the screen
#
partycommonhtml("", TRUE)
# <a href="http://www.stats.bris.ac.uk/~magpn/Research/Politics/whovote.htm">Return to <EM>Who to Vote For</EM> page</a>
}
\keyword{ datagen }% at least one, from doc/KEYWORDS

\eof
\name{partyprint}
\alias{partyprint}
\title{ Function suitable for use as the stateprintfn argument for pinktoe for the EDM example}
\description{
	In response to a variable (from the var component of the frame component of the relevant
	tree or \code{\link{rpart}} object this function issues perl commands which call functions
	in the partylib object (which can be supplied as a \code{requirelib} object for \code{\link{pinktoe}}
}
\usage{
partyprint(yval, file = "", append = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{yval}{ One of "Lab", "Con", "LDem", "UU", "PC", "SNP": parties in the British Political system }
  \item{file}{ perl file to write the output code to}
  \item{append}{ Should be TRUE}
}
\details{
	This file should produce perl code to do something when a yval is produced. A yval is one of the
	elements of the var column in the frame dataframe of a tree or \link{rpart} object. In this case
	the elements are all political parties indicated by the possibilities described in the \code{yval}
	argument to this function. Here perl code is generated which calls a function, one for each political
	party. See example below.
}
\value{ Nothing.  }
\references{ 
\url{http://www.stats.bris.ac.uk/~magpn/Research/Pinktoe/Welcome.html}
}
\author{Guy P Nason }

\seealso{ \code{\link{pinktoe}}}
\examples{
partyprint("Lab", file="", append=TRUE)
# &labour;
#
#
# So the perl function labour gets called.


}
\keyword{ datagen }% at least one, from doc/KEYWORDS

\eof
\name{partytittext}
\alias{partytittext}
\title{ Returns the variable label}
\description{
	For the EDM example the title text for each node is simply the EDM number which gets supplied as a character
	argument. So it just gets returned to be used as a title (for the eventual HTML page). Of course, one could modify this function
	to do something more complicated.
}
\usage{
partytittext(v)
}
\arguments{
  \item{v}{ A character string describing the variable under consideration, like "EDM29", etc}
}
\details{
	Just returns the variable name which is good enough for a title in this situation.
}
\value{
	Returns its argument, the variable name.
}
\references{ 
\url{http://www.stats.bris.ac.uk/~magpn/Research/Pinktoe/Welcome.html}
}
\author{Guy P Nason }
\note{ Not intended for general user use}

\seealso{ \code{\link{pinktoe}}}
\examples{
#
# Try it with the "EDM29" variable name
#
partytittext("EDM29")
# [1] "EDM29"
}
\keyword{ datagen }% at least one, from doc/KEYWORDS

\eof
\name{pinktoe}
\alias{pinktoe}
\title{Pinktoe: convert S trees to web files for interactive traversal.}
\description{
	Pinktoe converts a S tree object to a set of HTML and perl files
	that can be, once uploaded to a perl-aware web server,
	interactively traversed by a user with a web browser. This is
	useful for large trees or trees where the variables require
	description by verbose text.
}
\usage{
pinktoe(treeobj, textfn, tittext, treeid = "",
    cgibindir = paste("/~magpn/cgi-bin/", treeid, "/", sep = ""),
    htmldir = paste("/home/magpn/public_html/Research/Politics/TREE/",
    treeid, "/", sep = ""), localdir = "Tree/", stateprintfn = partyprint,
    requirelib = "../party.lib", commonhtml)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{treeobj}{ An object of class rpart (or tree in S) }
  \item{textfn}{ A user supplied function that prints out text to a file in response to a variable name.}
  \item{tittext}{ A user supplied function that prints out title text to a
	file in response to a variable name }
  \item{treeid}{ This is a character string which is appended to both
	\code{cgibindir} and \code{htmldir}.
	This can be useful when you are building
	web pages for a collection of trees and store different trees in
	separate directories. }
  \item{cgibindir}{ A character string containing the directory where the perl
	files generated by pinktoe (with the extension \code{.pl}) will be
	stored.  
	(This should be the directory part of the URL of the cgi-bin 
	directory). }

  \item{htmldir}{ A character string containing the directory where the HTML
		files generated by pinktoe (with the extension \code{.htm})
		will be stored.  (This should be a pathname understood and
		able to be found by perl).
}
  \item{localdir}{A local location to store both the HTML and perl files
	immediately after they are generated }

  \item{stateprintfn}{A user-supplied function that decides what to do when
	supplied with the \code{yval} reached at the leaf of a tree. Some 
	text can be output, or maybe a perl function call.  }

  \item{requirelib}{A library of perl functions that can be called by, e.g.
	\code{stateprintfn}. The library that this refers to
	should reside in the \code{cgibin} directory. If no function calls
	are planned then it doesn't matter what argument is supplied.}

  \item{commonhtml}{A user-supplied function that prints out some HTML code.
	This is appended to every HTML web page.}
}
\details{
	See the example below for usage. See
\url{http://www.stats.bris.ac.uk/~magpn/Research/Pinktoe/Welcome.html}
for a full description
}
\value{ No value is produced.  }
\references{ 
\url{http://www.stats.bris.ac.uk/~magpn/Research/Pinktoe/Welcome.html}
}
\author{Guy P Nason}
\note{ This is version 2, an earlier version didn't work well with R}

\seealso{ \code{\link{PT}}}
\examples{
#
# Attach rpart library
#
library("rpart")
data("mpincdf99")
#
# Create a tree (rpart object)
#
z.edm <- makeEDMtree()
#
# Plot the tree to see its basic structure.
#
plot(z.edm)
text(z.edm)
#
# Now use pinktoe to generate a set of htm and pl files that can be used
# by a CGI-enabled web server to traverse the tree.
#
data("edmbigtext")
#
# Next code requires "sfsmisc" library. This is not installed by default
# in R distributions so you'll have to get it yourself. We make sure
# that the next code doesn't run because R CMD check can't install packages (I think)
#
\dontrun{pinktoe(z.edm, edm.text, partytittext, treeid="", localdir="./",
    cgibindir="/~magpn/cgi-bin/TEST/",  
    htmldir="/home/magpn/public_html/TEST/", stateprintfn=partyprint, 
    requirelib="../party.lib", 
    commonhtml=partycommonhtml)  }
# Frame row number is  1 
# Node number is  1 
# Frame row number is  2 
# Node number is  2 
# Frame row number is  3 
# Node number is  4 
# Frame row number is  4 
# Node number is  8 
# Frame row number is  6 
# Node number is  17 
# Frame row number is  7 
# Node number is  34 
# Frame row number is  8 
# Node number is  68 
# Frame row number is  9 
# Node number is  136 
# Frame row number is  17 
# Node number is  3 
#
# If you look in the current directory you'll find a load of perl and
# HTML files created.
#
}
\keyword{ iplot }
\keyword{ tree }

\eof
\name{pv99tompall}
\alias{pv99tompall}
\docType{data}
\title{ Permutation vector from MP lists in 99 into the mpall3 database}
\description{
	In 1999 a selection of MPs signed Early Day Motions and hence turn up
	in databases that record which MPs signed in a given year. The lists 
	that record MPs signing records implicitly define an "index position"
	for those MPs in those records. To link these MPs to the global
	\code{\link{mpall3}} database this vector gives the index into
	\code{\link{mpall3}} from their implicity index position.
}
\usage{data(pv99tompall)}
\format{A permutation vector containing 549 integers each one identifying an MP
	and their position within the \code{\link{mpall3}} database.
}
\source{Nason, G.P. (2001) Early Day Motions: exploring backbench opinion during 1997-2000. \emph{Technical Report} 01:11, Department
 of Mathematics, University of Bristol.
}
\examples{
data(pv99tompall)
data(mpall3)
data(mpinc99)
#
# In the mpincdf object (which records EDM signings) Irene Adams is MP number 2. Let's check this
#
dimnames(mpinc99)[[1]][1:5]
#[1] "Abbott/Diane"      "Adams/Irene"       "Ainger/Nick"      
#[4] "Ainsworth/Peter"   "Alexander/Douglas"
#
# What number is she in the mpall3 database?
#
pv99tompall[2]
# [1] 3
#
# She is the third MP in this structure. (You see possibly number 1 or 2 in mpall3 did not sign anything
# in 1999.
#
# Let's check
#
mpall3$mpn[3]
#[1] Adams, Irene
#670 Levels: Abbott, Miss Diane Adams, Gerry# Adams, Irene ... Young, Rt Hon Sir George Bt
#
# Yep, that's her!
}
\keyword{datasets}

\eof
\name{splits.rpart}
\alias{splits.rpart}
\title{Create splits data frame that seems to be missing from R rpart code }
\description{
	The tree function in S returns a tree class object which has
	frame as one of its components. This frame has two columns called
	splits.cutleft and splits.cutright which illustrate how a variable
	split was a achieved for a given node. The R rpart function
	documentation says that it does produce these splits component
	but I have been unable to find it!! This function recreates,
	as best I can, the splits components which pinktoe makes use of.
}
\usage{
splits.rpart(tree, print.it = FALSE)
}
\arguments{
  \item{tree}{ The rpart object that you wish to produce splits info for }
  \item{print.it}{ If TRUE then informative messages are printed out (useful for debugging)   }
}
\details{ Produces the (missing) splits components for the frame
	component of an rpart object.
}
\value{ Returns a data.frame with two columns and the same number of
	rows as the frame component of the input tree object.
	The first (second) column contains information about the
	left hand (right hand) edge from a node.
}
\references{ None. }
\author{Guy P Nason}
\note{ Of course, the splits component could be lurking somewhere else
	in the rpart object but I have been unable to find it!}

\seealso{ \code{\link{pinktoe}}, \code{\link{PT}}}
\examples{
    library("rpart")
    data(kyphosis)	% Attach kyphosis data set
    z.kyphosis <- rpart(kyphosis) % Make CART tree
#
#   Now check that there is no splits.cutleft or splits.cutright component
#   of the frame component as there is in S
#
    dimnames(z.kyphosis$frame)[[2]]
#
#[1] "var"        "n"          "wt"         "dev"        "yval"      
#[6] "complexity" "ncompete"   "nsurrogate" "yval2"     
#
# Nope! So let's use our function to make them
#
    splits.rpart(z.kyphosis)
#
#  splits.cutleft splits.cutright
#1          >=8.5           < 8.5
#2         >=14.5          < 14.5
#3                               
#4           < 55            >=55
#5                               
#6          >=111           < 111
#7                               
#8                               
#9                               
#
# The resultant object could be installed into the frame component
# (as happens in the early code lines of PT and pinktoe) by
#
# z.kyphosis$frame <- cbind(z.kyphosis$frame, splits.rpart(z.kyphosis))
}
\keyword{ iplot }% at least one, from doc/KEYWORDS
\keyword{ tree }% __ONLY ONE__ keyword per line

\eof
\name{writehtml}
\alias{writehtml}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Write the HTML file for an EDM decision and return the names of the called perl files so that they can be constructed. }
\description{
	Part of the pinktoe suite this function writes the HTML files that a web server will serve. The content of these HTML
    files will be some explanatory text (generated by edmtextfn, edmtittext), with a check box that will record the answer to
    the question specified in the HTML file. These HTML files will be able to call perl files and their names are constructed
    by this function and returned (and later used by writeperl). 
}
\usage{
writehtml(edmlabel, uniqedmlab, edmtextfn, edmtittext, cgibindir, localdir, commonhtml, numvar, numstring, treeobj)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{edmlabel}{ The variable name (from the \code{var} field of the original tree) for this HTML file/question. }
  \item{uniqedmlab}{ HTML file is associated with a node which is a given split on a variable: a unique filename for each
	node should be supplied (genedmhtml generates this by combining the variable name with the node number).} 
  \item{edmtextfn}{ A function that can print out explanatory text given a variable name (see web help page and \code{\end{displaymath}.text} example. }
  \item{edmtittext}{ Prints out a title string given a variable name }
  \item{cgibindir}{ A character string containing the directory where the perl
        files generated by pinktoe (with the extension \code{.pl}) will be
        stored.
        (This should be the directory part of the URL of the cgi-bin
        directory). }

  \item{localdir}{A local location to store both the HTML and perl files
        immediately after they are generated }

  \item{commonhtml}{A user-supplied function that prints out some HTML code.
        This is appended to every HTML web page.}

  \item{numvar}{ Logical variable which is TRUE is the variable for this HTML is numeric, FALSE if it is a factor. }
  \item{numstring}{ The S character string which describes the split (either factor or numeric) for this variable. Basically one of the cells in the
		dataframe returned by \link{splits.rpart}}
  \item{treeobj}{ The rpart (or tree) object that this whole process is concerned with}
}
\details{
	Writes the HTML files
}
\value{The HTML file here creates a checkbox. The result of which causes a call to a perl function. The HTML file here creates the perl file name
	and passes it back to its calling function (\code{\link{genedmhtml}}) which then creates the perl function and supplies it with the file name.
	This function returns the perl filename.
}
\references{ 
\url{http://www.stats.bris.ac.uk/~magpn/Research/Pinktoe/Welcome.html}
}
\author{Guy P Nason }
\note{ Not intended for general user use}

\seealso{ \code{\link{pinktoe}}}
\examples{
#
#Not intended for general user use
#
}
\keyword{ internal }% at least one, from doc/KEYWORDS

\eof
\name{writeperl}
\alias{writeperl}
\title{ Writes the perl file(s) for pinktoe}
\description{
	A perl file needs to be written that works out whether a tick box has been checked and then calls either code to
	deal with a leaf or an HTML file for another decision to be made. 
}
\usage{
writeperl(childleftrow, childrightrow, treeobj, perlname, edmlabel, htmldir, edmix, stateprintfn, requirelib)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{childleftrow}{ The "left" hand row number possibility stemming from this node.}
  \item{childrightrow}{ The "right" hand row number possibility stemming from this node.}
  \item{treeobj}{ The \code{rpart} or \code{tree} object that this whole process is using}
  \item{perlname}{ The name of the perl file to construct (returned earlier from \code{\link{writehtml}}}
  \item{edmlabel}{ The variable name (from the \code{var} field of the original tree) for this HTML file/question. }
  \item{htmldir}{ A character string containing the directory where the HTML
                files generated by pinktoe (with the extension \code{.htm})
                will be stored.  (This should be a pathname understood and
                able to be found by perl).}

  \item{edmix}{ A vector of the node numbers (row names of the \$frame component of the tree)}
  \item{stateprintfn}{A user-supplied function that decides what to do when
        supplied with the \code{yval} reached at the leaf of a tree. Some
        text can be output, or maybe a perl function call.  }

  \item{requirelib}{A library of perl functions that can be called by, e.g.
        \code{stateprintfn}. The library that this refers to
        should reside in the \code{cgibin} directory. If no function calls
        are planned then it doesn't matter what argument is supplied.}

}
\details{
	The HTML file that preceeds the construction of the currently described perl file 
	describes a decision with two possible courses of action. These are coded in the \code{childleftrow}
	and \code{childrightrow} arguments. Perl code is written to work out whether the checkbox in the
	HTML code was ticked or note and then execute the relevant next HTML file or leaf code.
}
\value{
  No value returned.
}
\references{ 
\url{http://www.stats.bris.ac.uk/~magpn/Research/Pinktoe/Welcome.html}
}
\author{Guy P Nason }
\note{ Not intended for general user use}

\seealso{ \code{\link{pinktoe}}}
\examples{
#
#Not intended for general user use
#
}
\keyword{ internal }% at least one, from doc/KEYWORDS

\eof
\name{writeperloption}
\alias{writeperloption}
\title{
  Generate part of the perl file.
}
\description{ If \code{childvar} is a leaf then call \code{stateprintfn} to issue perl code to call appropriate leaf functionality,
	alternatively issue perl code to call next HTML file in the tree.}
\usage{
writeperloption(childvar, childrow, childnodeid, treeobj, perlname, append = TRUE, htmldir, stateprintfn)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{childvar}{ Variable name of next item in tree, either "<leaf>" or actual variable name}
  \item{childrow}{ The row number into frame for next item.}
  \item{childnodeid}{ The node number (row name of row number in frame component)}
  \item{treeobj}{ The \code{rpart} or \code{tree} object that all this is about}
  \item{perlname}{ The name of the perl file that all this is being written to}
  \item{append}{ Should be TRUE} 
  \item{htmldir}{ The directory that the HTML files are getting written to (the perl file needs to know this to set up a call to HTML files}
  \item{stateprintfn}{A user-supplied function that decides what to do when
        supplied with the \code{yval} reached at the leaf of a tree. Some
        text can be output, or maybe a perl function call.  }

}
\details{
	As description.
}
\value{
	No value returned.
}
\references{ 
\url{http://www.stats.bris.ac.uk/~magpn/Research/Pinktoe/Welcome.html}
}
\author{Guy P Nason }
\note{ Not intended for general user use}

\seealso{ \code{\link{pinktoe}}}
\examples{
#
#Not intended for general user use
#
}
\keyword{ internal }% at least one, from doc/KEYWORDS

\eof
